Powerbase: Watford Watford, England April 28th 2002 26 players Rob Treasure Deck Name: The Turd A real abomination of a deck, constructed initially taking advantage of Anneke's brilliant special to control the table but evolving into something much nastier. Interestingly I only had to use her special twice on the day and both of those times were in the final and saved VP's from dropping to someone else (not an acceptable situation:o). A evil VP sniper of a deck that puts the table under constant pressure and drops atom bombs with alarming regularity. The sleazy 2nd trad / Obedience (hmmm I do like the picture on Sabbat Obedience:o))) / Majesty combo allows you to stay untapped and block loads of actions. In the second round I was under serious pressure from Matt Stockton's weenie Pre deck and was pleased with the constant ability to block 5/6/7 weenies a turn whilst laying down the master phase bombs. Crypt (12 cards, min=32, max=44, avg=9.67) ------------------------------------------ 4x Anneke 10 AUS CEL PRE dom justicar Toreador:1 4x Anson 8 CEL PRE aus dom prince Toreador:1 3x Leandro 11 AUS OBF PRE cel dom inner circle Malkavian:2 1x Arika 11 DOM FOR OBF PRE aus cel inner circle Ventrue:2 Library (86 cards) Master (26) 6x Anarch Revolt 1x Elysium: The Arboretum 1x Giant's Blood 3x Information Highway 1x Life Boon 5x Minion Tap 2x Obfuscate 1x Parthenon, The 1x Secure Haven 2x Sudden Reversal 3x Temptation of Greater Power Action (3) 3x Fifth Tradition: Hospitality Political Action (13) 1x Ancient Influence 1x Ancilla Empowerment 4x Dramatic Upheaval 1x Meddling of Semsith, The 3x Parity Shift 1x Political Stranglehold 2x Protect Thine Own Action Modifier (8) 4x Cloak the Gathering 2x Lost in Crowds 2x Voter Captivation Reaction (31) 2x Forced Awakening 2x My Enemy's Enemy 13x Obedience 11x Second Tradition: Domain 2x Telepathic Misdirection Combat (6) 6x Majesty